sdv.constraints.ScalarRange
===========================

.. currentmodule:: sdv.constraints

.. autoclass:: ScalarRange

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ScalarRange.__init__
      ~ScalarRange.filter_valid
      ~ScalarRange.fit
      ~ScalarRange.fit_transform
      ~ScalarRange.from_dict
      ~ScalarRange.is_valid
      ~ScalarRange.reverse_transform
      ~ScalarRange.to_dict
      ~ScalarRange.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScalarRange.constraint_columns
   
   